==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ADoubleBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ADoubleBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a71851b20e9af987 soot_jimple_parser_node_ADoubleBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ADoubleBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ADoubleBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDouble$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$_init$04034813823afdc5(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TDouble$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TDouble$object *_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$getDouble$351388c6ad2156af(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$setDouble$3dabc10e226b31d3(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TDouble$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$getDouble$351388c6ad2156af;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$setDouble$3dabc10e226b31d3;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TDouble$object	*(*getDouble$351388c6ad2156af)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setDouble$3dabc10e226b31d3)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TDouble$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods	soot_jimple_parser_node_ADoubleBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TDouble$object	*__5fdouble__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs	soot_jimple_parser_node_ADoubleBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ADoubleBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADoubleBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADoubleBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ADoubleBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ADoubleBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a71851b20e9af987 soot_jimple_parser_node_ADoubleBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ADoubleBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ADoubleBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDouble$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$_init$04034813823afdc5(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TDouble$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TDouble$object *_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$getDouble$351388c6ad2156af(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$setDouble$3dabc10e226b31d3(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TDouble$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$getDouble$351388c6ad2156af;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$setDouble$3dabc10e226b31d3;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TDouble$object	*(*getDouble$351388c6ad2156af)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setDouble$3dabc10e226b31d3)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TDouble$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vmethods	soot_jimple_parser_node_ADoubleBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TDouble$object	*__5fdouble__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_refs	soot_jimple_parser_node_ADoubleBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ADoubleBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADoubleBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADoubleBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADoubleBaseTypeNoName_H_ */
